package com.chelvc.framework.rocketmq.config;

import lombok.RequiredArgsConstructor;
import org.apache.rocketmq.client.log.ClientLogger;
import org.apache.rocketmq.spring.support.RocketMQMessageConverter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.messaging.converter.MessageConverter;

/**
 * RocketMQ配置类
 *
 * @author Woody
 * @date 2023/4/5
 */
@Configuration
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class RocketMQConfigurer implements ApplicationRunner {
    static {
        System.setProperty(ClientLogger.CLIENT_LOG_USESLF4J, "true");
    }

    private final ApplicationContext applicationContext;

    @Bean
    @Primary
    public RocketMQMessageConverter rocketMQMessageConverter() {
        return new RocketMQMessageConverter() {
            private final MessageConverter messageConverter;

            {
                // 重置消息转换类，用于封装请求/认证上下文信息
                this.messageConverter = new MessageConverterWrapper(super.getMessageConverter(), false);
            }

            @Override
            public MessageConverter getMessageConverter() {
                return this.messageConverter;
            }
        };
    }

    @Override
    public void run(ApplicationArguments args) {
        RocketMQMessageConverter messageConverter = this.applicationContext.getBean(RocketMQMessageConverter.class);
        ((MessageConverterWrapper) messageConverter.getMessageConverter()).initializeApplicationContextCompleted();
    }
}
