package com.chelvc.framework.rocketmq.interceptor;

import com.chelvc.framework.base.context.SessionContextHolder;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;

/**
 * RocketMQ消费者拦截器
 *
 * @author Woody
 * @date 2023/4/5
 */
@Order
@Aspect
@Component
public class RocketMQConsumeInterceptor {
    /**
     * 拦截消息处理
     *
     * @param point 接口方法拦截点
     * @throws Throwable 接口调用异常
     */
    @Around("@within(org.apache.rocketmq.spring.annotation.RocketMQMessageListener)")
    public Object consume(ProceedingJoinPoint point) throws Throwable {
        try {
            return point.proceed();
        } finally {
            SessionContextHolder.clearSessionContext();
        }
    }
}
